A collection of useful scripts.

# Usage
## sdt_change_bpm.py
Transforms an SDT file written in one bpm to another

```python sdt_change_bpm.py /path/to/sdt ORIGINAL_BPM NEW_BPM```

## sdt_to_ma2_with_bpms.py
Converts an SDT file to a ma2 file which follows another ma2 file's bpm skeleton.

```python sdt_to_ma2_with_bpms.py /path/to/sdt /path/to/ma2/to/copy/bpm SDT_BPM```
